@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2009 Oprea Dan
+#    Copyright (C) 2008-2009 Oprea Dan, Bart de Koning, Richard Bailey
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -17,13 +17,23 @@
 
 
 import gtk
+import glib
+import gettext
+
+
+_=gettext.gettext
 
 
 def get_snapshot_display_markup( snapshots, snapshot_id ):
 	display_name = snapshots.get_snapshot_display_id( snapshot_id )
+
 	name = snapshots.get_snapshot_name( snapshot_id )
 	if len( name ) > 0:
-		display_name = display_name + ' - <b>' + name + '</b>'
+		display_name = display_name + ' - <b>' + glib.markup_escape_text( name ) + '</b>'
+	
+	if snapshots.is_snapshot_failed( snapshot_id ):
+		display_name = display_name + " (<b>%s</b>)" % _("WITH ERRORS !")
+
 	return display_name
 
 
